@@ -1,7 +1,11 @@
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
+
 import os
 
 from .base import NullBrowser, ExecutorBrowser, require_arg
-from ..executors import get_executor_kwargs
+from ..executors import executor_kwargs
 from ..executors.executorservo import ServoTestharnessExecutor
 
 here = os.path.join(os.path.split(__file__)[0])
@@ -11,7 +15,7 @@ __wptrunner__ = {"product": "servo",
                  "browser": "ServoBrowser",
                  "executor": {"testharness": "ServoTestharnessExecutor"},
                  "browser_kwargs": "browser_kwargs",
-                 "executor_kwargs": "get_executor_kwargs",
+                 "executor_kwargs": "executor_kwargs",
                  "env_options": "env_options"}
 
 
