@@ -62,7 +62,7 @@ def update_expected(test_root, metadata_root, log_file_names, rev_old=None, rev_
 
     write_changes(metadata_root, expected_map)
 
-    results_changed = [item for item in expected_map.itervalues() if item.modified]
+    results_changed = [item.test_path for item in expected_map.itervalues() if item.modified]
 
     return unexpected_changes(change_data, results_changed)
 
@@ -80,7 +80,7 @@ def files_in_repo(repo_root):
 
 
 def rev_range(rev_old, rev_new, symmetric=False):
-    joiner = ".." if not symmetric else ".."
+    joiner = ".." if not symmetric else "..."
     return "".join([rev_old, joiner, rev_new])
 
 
@@ -105,11 +105,7 @@ def load_change_data(rev_old, rev_new, repo):
 
 
 def unexpected_changes(change_data, files_changed):
-    rv = []
-    for fn in files_changed:
-        if change_data.get(fn) != "M":
-            rv.append(fn)
-    return rv
+    return [fn for fn in files_changed if change_data.get(fn) != "M"]
 
 # For each testrun
 # Load all files and scan for the suite_start entry
@@ -151,7 +147,7 @@ def write_changes(metadata_path, expected_map):
                     os.path.join(temp_path, "MANIFEST.json"))
 
     # Then move the old manifest files to a new location
-    temp_path_2 = metadata_path + str(uuid.uuid4)
+    temp_path_2 = metadata_path + str(uuid.uuid4())
     os.rename(metadata_path, temp_path_2)
     # Move the new files to the destination location and remove the old files
     os.rename(temp_path, metadata_path)
@@ -177,7 +173,6 @@ class ExpectedUpdater(object):
         self.expected_tree = expected_tree
         self.id_path_map = id_path_map
         self.ignore_existing = ignore_existing
-        print "ignore_existing", ignore_existing
         self.run_info = None
         self.action_map = {"suite_start": self.suite_start,
                            "test_start": self.test_start,
@@ -223,7 +218,7 @@ class ExpectedUpdater(object):
         result = test_cls.subtest_result_cls(
             data["subtest"],
             data["status"],
-            data["message"] if "message" in data else None)
+            data.get("message"))
 
         subtest.set_result(self.run_info, result)
 
@@ -234,7 +229,7 @@ class ExpectedUpdater(object):
 
         result = test_cls.result_cls(
             data["status"],
-            data["message"] if "message" in data else None)
+            data.get("message"))
 
         test.set_result(self.run_info, result)
         del self.test_cache[test_id]
@@ -243,12 +238,9 @@ class ExpectedUpdater(object):
 def create_test_tree(metadata_path, manifest):
     expected_map = {}
     test_id_path_map = {}
-    exclude_types = frozenset(["helper", "manual"])
-    for test_path, tests in manifest:
-        # This is a very silly way to exclude types
-        # but the API in manifest.py should be updated
-        if list(tests)[0].item_type in exclude_types:
-            continue
+    exclude_types = frozenset(["stub", "helper", "manual"])
+    include_types = set(manifest.item_types) ^ exclude_types
+    for test_path, tests in manifest.itertypes(*include_types):
 
         expected_data = load_expected(metadata_path, test_path, tests)
         if expected_data is None:
